@@ -1418,10 +1418,31 @@ class LoadMaster(BaseKempAppliance):
         virt_serv.populate_default_attributes(service)
         return virt_serv
 
-    def get_all_objects(self):
+    def get_all_objects(self, with_timestamp=False):
+        """
+        Fetches all virtual services from a LoadMaster, with
+        nested sub virtual services and real servers.
+        Optionally returns the last-changed timestamp
+        of the LoadMaster's virtual service configuration.
+
+        :param with_timestamp: Determines whether or not the last-changed
+                                timestamp should be returned
+        :type with_timestamp: bool
+        :return: If ``with_timestamp`` is False,
+                    a list of virtual services objects
+                    If ``with_timestamp`` is True,
+                    a tuple consisting of a list of virtual services objects
+                    and the last-changed timestamp
+        :rtype: Union[list, tuple]
+        """
+        # pylint: disable=too-many-locals
         # x variables are the object while x_data is the OrderedDict
         virtual_services = []
-        response = self._get("/listvs")
+        if with_timestamp:
+            response = self._get("/listvs",
+                                 parameters={"timestamp": 0})
+        else:
+            response = self._get("/listvs")
         # build_virtual_service's response parameter
         # must be a full response dict for regular VS
         # and the Data portion of response dict for sub VS
@@ -1452,8 +1473,11 @@ class LoadMaster(BaseKempAppliance):
                 for top_level_vs in virtual_services:
                     if subvs.index == top_level_vs.index:
                         subvs.real_servers = top_level_vs.real_servers
-
-        return virtual_services
+        if with_timestamp:
+            # Extract the last-changed timestamp if present
+            return virtual_services, int(data.get('timestamp', 0))
+        else:
+            return virtual_services
 
     def clone_virtual_service(self, service, ip=None, port=None, protocol=None,
                               enable=True,
